##############################################################################
#
#    Accounting Reports, for Odoo
#    Copyright © 2024 XCG Consulting <https://xcg-consulting.fr>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from odoo import api, fields, models


class AccountConsultationType(models.Model):
    """Dialog box entry corresponding to an account type."""

    _name = "account.consultation.type"
    _description = "Account consultation dialog box - Account type"

    _rec_name = "account_type"

    @api.model
    def selection_account_type(self):

        return self.env["account.account"].fields_get(
            allfields=["account_type"], attributes=["selection"]
        )["account_type"]["selection"]

    account_type = fields.Selection(
        selection=selection_account_type,
        string="Account Type",
        index=True,
        required=True,
        readonly=True,
    )

    _sql_constraints = [
        ("unique_account_type", "UNIQUE(account_type)", "The account type is unique.")
    ]

    @api.model
    def initialize_account_types(self):

        return self.sudo().create(
            [
                {"account_type": account_type}
                for account_type in dict(self.selection_account_type()).keys()
            ]
        )
