##############################################################################
#
#    Accounting Reports, for Odoo
#    Copyright © 2015, 2019, 2022 XCG Consulting <https://xcg-consulting.fr>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from odoo import fields, models


class Invoice(models.Model):
    """Adapt invoices (account.move) to reporting needs:
    - "Paid amount" field.
    """

    _inherit = "account.move"

    def _get_paid_amount(self):
        for record in self:
            record.paid_amount = (
                (record.amount_total or 0.0) - (record.amount_residual or 0.0)
                if record.state != "draft"
                else 0.0  # in 11.0 residual = 0 when draft so force this to 0.
            )

    paid_amount = fields.Monetary(
        compute=_get_paid_amount,
        compute_sudo=True,
        string="Paid amount",
        help="amount_total - amount_residual",
    )
