##############################################################################
#
#    Accounting Reports, for Odoo
#    Copyright © 2015, 2022 XCG Consulting <https://xcg-consulting.fr>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from odoo import api, fields, models


class AccountingEntry(models.Model):
    """Adapt accounting entries to reporting needs:
    - Add a balance which is simply debit - credit.
    """

    _inherit = "account.move.line"

    @api.depends("debit", "credit")
    def _get_reporting_balance(self):
        for rec in self:
            rec.reporting_balance = (rec.debit or 0.0) - (rec.credit or 0.0)

    reporting_balance = fields.Monetary(
        compute=_get_reporting_balance,
        string="Balance (reporting)",
        help="debit - credit",
        store=True,
    )
